Index: /issm/trunk-jpl/src/m/modules/ContourToNodes.m
===================================================================
--- /issm/trunk-jpl/src/m/modules/ContourToNodes.m	(revision 22939)
+++ /issm/trunk-jpl/src/m/modules/ContourToNodes.m	(revision 22940)
@@ -6,5 +6,5 @@
 %
 %   x,y: list of nodes
-%   contourname: name of .exp file containing the contours, or resulting structure from call to expread
+%   contourname: name of Argus or Shape file containing the contours, or resulting structure from call to expread
 %   edgevalue: integer (0, 1 or 2) defining the value associated to the nodes on the edges of the polygons
 %   flags: vector of flags (0 or 1), of size nodes
@@ -16,4 +16,17 @@
 end
 
+%Some conversion of files:  
+if ischar(contourname),
+	[path,name,ext]=fileparts(contourname); 
+	if strcmpi(ext,'.shp'),
+		%read contour from shapefile:
+		contour=shpread(contourname); 
+
+		%write it to a temporary filename: 
+		contourname=tempname; 
+		expwrite(contour,contourname);
+	end
+end
+
 %Call mex module
 [flags] = ContourToNodes_matlab(x,y,contourname,edgevalue);

Index: /issm/trunk-jpl/src/m/modules/ContourToMesh.m
===================================================================
--- /issm/trunk-jpl/src/m/modules/ContourToMesh.m	(revision 22939)
+++ /issm/trunk-jpl/src/m/modules/ContourToMesh.m	(revision 22940)
@@ -6,5 +6,5 @@
 %	
 %   index,x,y: mesh triangulation
 %   contourname: name of .exp file containing the contours.
 %   interptype: string defining type of interpolation ('element', or 'node').
 %   edgevalue: integer (0, 1, or 2) defining the value associated to the nodes on the edges of the polygons.
@@ -25,4 +25,15 @@
 end
 
+%Some conversion of files: 
+[path,name,ext]=fileparts(contourname); 
+if strcmpi(ext,'.shp'),
+	%read contour from shapefile:
+	contour=shpread(contourname); 
+
+	%write it to a temporary filename: 
+	contourname=[tempname '.exp'];
+	expwrite(contour,contourname);
+end
+
 %Call mex module
 [in_nod,in_elem] = ContourToMesh_matlab(index,x,y,contourname,interptype,edgevalue);
@@ -6,5 +6,5 @@
 %	
 %   index,x,y: mesh triangulation
-%   contourname: name of .exp file containing the contours.
+%   contourname: name of .exp or .shp file containing the contours.
 %   interptype: string defining type of interpolation ('element', or 'node').
 %   edgevalue: integer (0, 1, or 2) defining the value associated to the nodes on the edges of the polygons.